diff --git a/src/arch/x86/lib/cbfs_and_run.c b/src/arch/x86/lib/cbfs_and_run.c
index 6379842..be7d7ec 100644
--- a/src/arch/x86/lib/cbfs_and_run.c
+++ b/src/arch/x86/lib/cbfs_and_run.c
@@ -27,13 +27,13 @@ static void cbfs_and_run_core(const char *filename)
 	u8 *dst;
 
 	timestamp_add_now(TS_START_COPYRAM);
-	print_debug("Loading image.\n");
+	printk(BIOS_WARNING, "Loading image.\n");
 	dst = cbfs_load_stage(CBFS_DEFAULT_MEDIA, filename);
 	if ((void *)dst == (void *) -1)
 		die("FATAL: Essential component is missing.\n");
 
 	timestamp_add_now(TS_END_COPYRAM);
-	print_debug("Jumping to image.\n");
+	printk(BIOS_WARNING, "Jumping to image.\n");
 	__asm__ volatile (
 		"jmp  *%%edi\n"
 		:: "D"(dst)
diff --git a/src/cpu/amd/car/post_cache_as_ram.c b/src/cpu/amd/car/post_cache_as_ram.c
index 2e64416..617133f 100644
--- a/src/cpu/amd/car/post_cache_as_ram.c
+++ b/src/cpu/amd/car/post_cache_as_ram.c
@@ -28,6 +28,76 @@ static void inline __attribute__((always_inline))  memcopy(void *dest, const voi
 			: "memory", "cc");
 }
 
+
+static void __console_tx_nibble(unsigned nibble)
+{
+	unsigned char digit;
+	digit = nibble + '0';
+	if (digit > '9') {
+		digit += 39;
+	}
+	uart8250_tx_byte(CONFIG_TTYS0_BASE, digit);
+}
+
+static void  __console_tx_char(unsigned char byte)
+{
+	uart8250_tx_byte(CONFIG_TTYS0_BASE, byte);
+}
+
+#if 0
+static void __console_tx_hex8(unsigned char value)
+{
+	__console_tx_nibble((value >>  4U) & 0x0fU);
+	__console_tx_nibble(value & 0x0fU);
+}
+
+static void __console_tx_hex16(unsigned short value)
+{
+	__console_tx_nibble((value >> 12U) & 0x0fU);
+	__console_tx_nibble((value >>  8U) & 0x0fU);
+	__console_tx_nibble((value >>  4U) & 0x0fU);
+	__console_tx_nibble(value & 0x0fU);
+}
+#endif
+
+static void __console_tx_hex32(unsigned int value)
+{
+	__console_tx_nibble((value >> 28U) & 0x0fU);
+	__console_tx_nibble((value >> 24U) & 0x0fU);
+	__console_tx_nibble((value >> 20U) & 0x0fU);
+	__console_tx_nibble((value >> 16U) & 0x0fU);
+	__console_tx_nibble((value >> 12U) & 0x0fU);
+	__console_tx_nibble((value >>  8U) & 0x0fU);
+	__console_tx_nibble((value >>  4U) & 0x0fU);
+	__console_tx_nibble(value & 0x0fU);
+}
+
+#if 0
+static void __console_tx_string(const char *str)
+{
+	unsigned char ch;
+	while((ch = *str++) != '\0') {
+		if (ch == '\n')
+			__console_tx_char('\r');
+		__console_tx_char(ch);
+	}
+}
+#endif
+
+static void bt(void)
+{
+	u32 dummy;
+	u32 *sp = &dummy;
+	__console_tx_char('\n');
+	while ((u32)sp < 0x0001ff8c0) { /* RAMTOP - car_size */
+		__console_tx_hex32((u32)sp);
+		__console_tx_char(' ');
+		__console_tx_hex32(*sp);
+		__console_tx_char('\n');
+		sp++;
+	}
+}
+
 #define PRINTK_IN_CAR	1
 #define ACTUAL_CAR_SIZE	1
 
@@ -94,8 +164,11 @@ static void prepare_ramstage_region(void *resume_backup_memory)
 	print_car_debug("Prepare ramstage memory region... ");
 #if CONFIG_HAVE_ACPI_RESUME
 	if (resume_backup_memory) {
+		bt();
 		memcpy_(resume_backup_memory, (void *) CONFIG_RAMBASE, HIGH_MEMORY_SAVE - backup_top);
+		bt();
 		memset_((void*) CONFIG_RAMBASE, 0, HIGH_MEMORY_SAVE - backup_top);
+		bt();
 	}
 #endif
 	if (!resume_backup_memory)
diff --git a/src/lib/cbfs.c b/src/lib/cbfs.c
index 1f44695..3cfa24d 100644
--- a/src/lib/cbfs.c
+++ b/src/lib/cbfs.c
@@ -283,7 +283,7 @@ void * cbfs_load_stage(struct cbfs_media *media, const char *name)
 	memset((void *)((uintptr_t)stage->load + final_size), 0,
 	       stage->memlen - final_size);
 
-	DEBUG("stage loaded.\n");
+	printk(BIOS_WARNING, "stage loaded.\n");
 
 	entry = stage->entry;
 	// entry = ntohll(stage->entry);
